searchData={"items":[{"type":"module","title":"Akismet","doc":"Easily check comments with Akismet from Elixir.\n\nNote: You need to provide `AKISMET_KEY` as an environment variable.","ref":"Akismet.html"},{"type":"module","title":"Examples - Akismet","doc":"Export your Akismet key...\n```sh\nexport AKISMET_KEY='myakismetkey123'\n```\n\nThen use this library from Elixir:\n```elixir\n{:ok, akismet} = Akismet.init(\"https://example.com\")\nresult0 = Akismet.check_comment(akismet, user_ip, [comment_content: content, comment_author_email: email, ...])\nresult1 = Akismet.submit_spam(akismet, user_ip, [comment_content: content, comment_author_email: email, ...])\nresult2 = Akismet.submit_ham(akismet, user_ip, [comment_content: content, comment_author_email: email, ...])\n{:ok, %{limit: limit, usage: usage, percentage: pct, throttled: throttled}} = Akismet.usage_limit(akismet)\n```\n\n(You should probably handle errors, these are just quick examples.)","ref":"Akismet.html#module-examples"},{"type":"function","title":"Akismet.check_comment/3","doc":"Check a comment.\n\nArguments:\n\n- the struct returned by `init/1`,\n- the IP of the commenter,\n- and [extra parameters](https://akismet.com/developers/comment-check/) in the format\n`[user_agent: value, comment_type: value]`, etc.\n\nReturns\n\n- `:spam`,\n- `:discard_spam`: Akismet says the comment is [\"blatant spam\"](https://akismet.com/blog/theres-a-ninja-in-your-akismet/) and does not need to be stored,\n- `:ham`,\n- `{:akismet_error, \"debug help\"}`: Akismet returned an error and the second element\n  is the help/debugging message, if it exists.\n- or `:error`: could not access the Akismet endpoint.","ref":"Akismet.html#check_comment/3"},{"type":"function","title":"Akismet.init/1","doc":"Initializes the client. This verifies the API key, set in the environment\nvariable `AKISMET_KEY`.\n\nReturns\n\n- `{:ok, Akismet}`: API key is valid and successfully verified,\n- `:key_not_set`: the environment variable `AKISMET_KEY` is not set,\n- `:invalid_key`: your API key is not valid,\n- or `:error`: couldn't access the Akismet endpoint.","ref":"Akismet.html#init/1"},{"type":"function","title":"Akismet.submit_ham/3","doc":"Submit ham.\n\nArguments:\n\n- the struct returned by `init/1`,\n- the IP of the commenter,\n- and [extra parameters](https://akismet.com/developers/comment-check/) in the format\n`[user_agent: value, comment_type: value]`, etc.\n\nReturns\n\n- `:success`: submitted spam successfully,\n- `:failed`: failed to submit spam,\n- or `:error`: could not access the Akismet endpoint.","ref":"Akismet.html#submit_ham/3"},{"type":"function","title":"Akismet.submit_spam/3","doc":"Submit spam.\n\nArguments:\n\n- the struct returned by `init/1`,\n- the IP of the commenter,\n- and [extra parameters](https://akismet.com/developers/comment-check/) in the format\n`[user_agent: value, comment_type: value]`, etc.\n\nReturns\n\n- `:success`: submitted spam successfully,\n- `:failed`: failed to submit spam,\n- or `:error`: could not access the Akismet endpoint.","ref":"Akismet.html#submit_spam/3"},{"type":"function","title":"Akismet.usage_limit/1","doc":"Get usage limit.\n\nArguments:\n\n- the struct returned by `init/1`,\n\nReturns:\n\n- `{:ok, %{limit: _, usage: _, percentage: _, throttled: _}}` (see\n  [Akismet docs on usage limit](https://akismet.com/developers/usage-limit/))\n- `:error`: could not access Akismet endpoint","ref":"Akismet.html#usage_limit/1"}],"content_type":"text/markdown"}